==> tencentcloud-sdk-java-3.0.32-sources.jar: com/tencentcloudapi/yunjing/v20180228/models/RecoverMalwaresRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.yunjing.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class RecoverMalwaresRequest  extends AbstractModel{

    /**
    * 木马Id数组,单次最大删除不能超过200条
    */
    @SerializedName("Ids")
    @Expose
    private Integer [] Ids;

    /**
     * 获取木马Id数组,单次最大删除不能超过200条
     * @return Ids 木马Id数组,单次最大删除不能超过200条
     */
    public Integer [] getIds() {
        return this.Ids;
    }

    /**
     * 设置木马Id数组,单次最大删除不能超过200条
     * @param Ids 木马Id数组,单次最大删除不能超过200条
     */
    public void setIds(Integer [] Ids) {
        this.Ids = Ids;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "Ids.", this.Ids);

    }
}

==> tencentcloud-sdk-java-3.1.57-sources.jar: com/tencentcloudapi/yunjing/v20180228/models/RecoverMalwaresRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.yunjing.v20180228.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class RecoverMalwaresRequest extends AbstractModel{

    /**
    * 木马Id数组,单次最大删除不能超过200条
    */
    @SerializedName("Ids")
    @Expose
    private Long [] Ids;

    /**
     * Get 木马Id数组,单次最大删除不能超过200条 
     * @return Ids 木马Id数组,单次最大删除不能超过200条
     */
    public Long [] getIds() {
        return this.Ids;
    }

    /**
     * Set 木马Id数组,单次最大删除不能超过200条
     * @param Ids 木马Id数组,单次最大删除不能超过200条
     */
    public void setIds(Long [] Ids) {
        this.Ids = Ids;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "Ids.", this.Ids);

    }
}
